@@ -53,7 +53,7 @@ if ($file =~ /plot|graph|all/) {
       @not_yet_defined{qw(
 	plotbox plotcolor plotcursor plotdraw ploth plothraw plotinit plotlines
 	plotmove plotpoints plotrline plotrmove plotrpoint psdraw psploth
-	psplothraw
+	psplothraw plotscale
 	plotkill
       )} = (1) x 10000;
       $skip_gnuplot = 1;
@@ -198,6 +198,7 @@ sub process_cond {
 
 sub process_test {
   my ($in, $noans, $out) = @_;
+  my $ini_time = time;
   my $doprint;
   $doprint = 1 if $noans eq 'print';
   my $was_prev = $prev;
@@ -380,11 +381,14 @@ sub process_test {
       $in =~ s/(^|\G|\W)([-+]?)(\d+(\.\d*)?)(.?)/$1 $2 PARI($3) $5/g;
       # Big integer constants:
       $in =~ s/\bPARI\((\d{10,})\)/PARI('$1')/g;
-    } elsif ($in =~ /\b(elllseries|binomial|mathilbert|intnum|intfuncinit)\b/) { # high precision needed?
+    } elsif ($in =~ /\b(elllseries|binomial|mathilbert|intnum|intfuncinit|intfuncinit)\b/) { # high precision needed?
       # XXXX Primitive!
       # Substitute constants where they are not arguments to functions,
       # (except small half-integers, which should survive conversion)
       $in =~ s/(^|\G|\W)([-+]?)(?!\d{0,6}\.5\b)(\d+\.\d*)/$1 $2 PARI('$3') /g;
+      # Bug in GP???  Too sensitive to precision of 4.5 in intfuncinit(t=[-oo, 4.5],[oo, 4.5], gamma(2+I*t)^3, 1);
+      $in =~ s/(^|\G|\W)([-+]?)(\d+\.\d*)/$1 $2 PARI('$3') /g
+	if $in =~ /intfuncinit/;
       # Big integer constants:
       $in =~ s/\bPARI\((\d{10,})\)/PARI('$1')/g;
     } else {
@@ -402,11 +406,14 @@ sub process_test {
     $in =~ s/\b(|p|tex)print(tex|)\(/ 'my_' . $1 . $2 . 'print(1,' /ge;
     $in =~ s/\b(|p|tex)print1\(/ 'my_' . $1 . 'print(0,'/ge;
     $in =~ s/\b(eval|shift|sort)\(/&$1\(/g; # eval($y)
-    # Recognize variables
+    # Special case -oo (with $oo=[PARI(1)] done earlier;
+    # Having $oo defined without external PARI tests conversions; but it'sn't overloaded
+    $in =~ s/-oo\b/- PARI(\$oo)/ if $seen_now{oo} or 1;
+    # Recognize variables and prepend $ in assignments
     # s/\b(direuler\s*\(\s*\w+\s*),/$1=/;	# direuler
     $in =~ s/\bX\b/PARIvar("X")/g if $in =~ /\bdireuler\b/;
-    $in =~ s/(^|[;(])(\w+)(\s*=\s*)/$seen_now{$2} = '$'; $1 . '$' . $2 . $3/ge; # Assignment
-    # Substitute variables (not before '^' - inside of 'o(x^17)'):
+    $in =~ s/(^\s*|[;(]\s*)(?=(\w+)\s*=\s*)/$seen_now{$2} = '$'; $1 . '$'/ge; # Assignment
+    # Prepend $ to variables (not before '^' - inside of 'o(x^17)'):
     $in =~ s/(^|[^\$])\b([a-zA-Z]\w*)\b(?!\s*[\(^])/
       		($1 || '') . ($seen{$2} || $seen_now{$2} || '') . $2
 	/ge;
@@ -621,7 +628,9 @@ sub process_test {
 				      forstep )\b/x);
     # Remove the value from texprint:
     # pop @$out if $in =~ /texprint/ and @$out == 2;
+    my $pre_time = time() - $ini_time;
     $res = eval "$in";
+    my $run_time = time() - $ini_time - $pre_time;
     $rres = $res;
     $rres = pari_print $res if defined $res and ref $res;
     my $re_out;
@@ -691,11 +700,14 @@ sub process_test {
       if ($@ =~ /^Undefined subroutine &main::(\w+)/
 	  and $not_yet_defined{$1}) {
 	print "# in='$in'\nok $current_num # Skipped: `$1' is known to be undefined\n";
+      } elsif ($@ =~ /high resolution graphics disabled/
+	       and not Math::Pari::have_graphics()) {
+	print "# in='$in'\nok $current_num # Skipped: graphic is disabled in this build\n";
       } elsif ($@ =~ /gnuplot-like plotting environment not loaded yet/
 	       and $skip_gnuplot) {
 	print "# in='$in'\nok $current_num # Skipped: Term::Gnuplot is not loaded\n";
-      } else {
-	print "not ok $current_num # in='$in', err='$@'\n";
+      } else {			# XXXX Parens needed???
+	nok_print( $current_num, $in, "not ok $current_num # in='$in', err='$@'\n" );
       }
       return;
     }
@@ -709,29 +721,37 @@ sub process_test {
 	return;
       }
     }
+    my $post_time = time() - $ini_time - $pre_time - $run_time;
     if (not $noans and defined $re_out
 	     and (not defined $rres or not $cmp)) {
       $out->[0] =~ s/\n/\t/g;	# @$out usually has 1 elt
-      print "not ok $current_num # in='$in'\n#    out='", $rres, "', type='", ref $res,
+      nok_print $current_num, $in, "not ok $current_num # in='$in'\n#    out='", $rres, "', type='", ref $res,
       "'\n# pari==='", join("\t", @$out), "'\n# re_out='$re_out'\n";
     } elsif (not $noans and defined $re_out) {
-      print "ok $current_num\n";
+      print "ok $current_num #  run_time=$run_time, post_time=$post_time, pre_time=$pre_time\n";
       @seen{keys %seen_now} = values %seen_now;
       $prev = $res;
     } elsif (not $noans and (not defined $rres or $rres ne $rout)) {
-      print "not ok $current_num # in='$in'\n#    out='", $rres, "', type='", ref $res,
+      nok_print $current_num, $in, "not ok $current_num # in='$in'\n#    out='", $rres, "', type='", ref $res,
       "'\n# expect='$rout'\n";
     } elsif ($doprint and $printout ne $rout) {
-      print "not ok $current_num # in='$in'\n# printout='", $printout,
+      nok_print $current_num, $in, "not ok $current_num # in='$in'\n# printout='", $printout,
       "'\n#   expect='$rout', type='", ref $res,"'\n";
     } else {
-      print "ok $current_num\n";
+      print "ok $current_num #  run_time=$run_time, post_time=$post_time, pre_time=$pre_time\n";
       @seen{keys %seen_now} = values %seen_now;
       $prev = $res;
     }
   }
 }
 
+sub nok_print {
+  my ($n, $in) = (CORE::shift, CORE::shift);
+  print(@_), return unless $ENV{AUTOMATED_TESTING};
+  warn("# in = `$in'\n", @_);
+  print("not ok $n\n");
+}
+
 sub process_error {
   my ($in, $out, $error) = @_;
   $current_num++;
